@@ -1,7 +1,7 @@
 /*
  * alloc - storage allocation and storage debug macros
  *
- * Copyright (C) 1999  David I. Bell
+ * Copyright (C) 1999-2007,2014  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -15,11 +15,11 @@
  * A copy of version 2.1 of the GNU Lesser General Public License is
  * distributed with calc under the filename COPYING-LGPL.  You should have
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 29.4 $
- * @(#) $Id: alloc.h,v 29.4 2001/06/08 21:00:58 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/alloc.h,v $
+ * @(#) $Revision: 30.5 $
+ * @(#) $Id: alloc.h,v 30.5 2014/08/24 21:56:51 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/alloc.h,v $
  *
  * Under source code control:	1990/02/15 01:48:29
  * File existed as early as:	before 1990
@@ -28,57 +28,47 @@
  */
 
 
-#if !defined(__ALLOC_H__)
-#define __ALLOC_H__
+#if !defined(INCLUDE_ALLOC_H)
+#define INCLUDE_ALLOC_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
-# include "calc/have_malloc.h"
 # include "calc/have_newstr.h"
 # include "calc/have_string.h"
 # include "calc/have_memmv.h"
 #else
-# include <calc/have_malloc.h>
 # include <calc/have_newstr.h>
 # include <calc/have_string.h>
 # include <calc/have_memmv.h>
 #endif
 
-#ifndef HAVE_MALLOC_H
-#if defined(FORCE_STDC) || (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
-   extern void *malloc();
-   extern void *realloc();
-   extern void free();
-# else
-   extern char *malloc();
-   extern char *realloc();
-   extern void free();
-# endif
-#endif
-
 #ifdef HAVE_STRING_H
 # include <string.h>
 
 #else
+#if defined(_WIN32) && defined(NOTCYGWIN)
+#include <stdio.h>
+#endif
 
 # if defined(HAVE_NEWSTR)
-extern void *memcpy();
-extern void *memset();
-#if defined(FORCE_STDC) || (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
-extern size_t strlen();
+E_FUNC void *memcpy();
+E_FUNC void *memset();
+#if defined(FORCE_STDC) || \
+   (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
+E_FUNC size_t strlen();
 #  else
-extern long strlen();
+E_FUNC long strlen();
 #  endif
 # else /* HAVE_NEWSTR */
-extern void bcopy();
-extern void bfill();
-extern char *index();
+E_FUNC void bcopy();
+E_FUNC void bfill();
+E_FUNC char *index();
 # endif /* HAVE_NEWSTR */
-extern char *strchr();
-extern char *strcpy();
-extern char *strncpy();
-extern char *strcat();
-extern int strcmp();
+E_FUNC char *strchr();
+E_FUNC char *strcpy();
+E_FUNC char *strncpy();
+E_FUNC char *strcat();
+E_FUNC int strcmp();
 
 #endif
 
@@ -92,13 +82,14 @@ extern int strcmp();
 #endif /* HAVE_NEWSTR */
 
 #if !defined(HAVE_MEMMOVE)
-# undef CALC_SIZE_T
-#if defined(FORCE_STDC) || (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
-#  define CALC_SIZE_T size_t
+# undef MEMMOVE_SIZE_T
+#if defined(FORCE_STDC) || \
+   (defined(__STDC__) && __STDC__ != 0) || defined(__cplusplus)
+#  define MEMMOVE_SIZE_T size_t
 # else
-#  define CALC_SIZE_T long
+#  define MEMMOVE_SIZE_T long
 # endif
-extern void *memmove(void *s1, const void *s2, CALC_SIZE_T n);
+E_FUNC void *memmove(void *s1, CONST void *s2, MEMMOVE_SIZE_T n);
 #endif
 
-#endif /* !__ALLOC_H__ */
+#endif /* !INCLUDE_ALLOC_H */
