@@ -1,7 +1,7 @@
 /*
  * config - configuration routines
  *
- * Copyright (C) 1999-2002  Landon Curt Noll and David I. Bell
+ * Copyright (C) 1999-2007,2014  Landon Curt Noll and David I. Bell
  *
  * Primary author:  Landon Curt Noll
  *
@@ -17,11 +17,11 @@
  * A copy of version 2.1 of the GNU Lesser General Public License is
  * distributed with calc under the filename COPYING-LGPL.  You should have
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 29.12 $
- * @(#) $Id: config.h,v 29.12 2002/12/29 09:20:25 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/config.h,v $
+ * @(#) $Revision: 30.4 $
+ * @(#) $Id: config.h,v 30.4 2014/08/24 21:56:51 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/config.h,v $
  *
  * Under source code control:	1995/11/01 22:20:17
  * File existed as early as:	1995
@@ -31,16 +31,16 @@
  */
 
 
-#if !defined(__CONFIG_H__)
-#define __CONFIG_H__
+#if !defined(INCLUDE_CONFIG_H)
+#define INCLUDE_CONFIG_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
-# include "calc/win32dll.h"
+# include "calc/decl.h"
 # include "calc/nametype.h"
 # include "calc/qmath.h"
 #else
-# include <calc/win32dll.h>
+# include <calc/decl.h>
 # include <calc/nametype.h>
 # include <calc/qmath.h>
 #endif
@@ -78,19 +78,26 @@
 #define CONFIG_MORE	25
 #define CONFIG_BLKMAXPRINT 26
 #define CONFIG_BLKVERBOSE 27
-#define CONFIG_BLKBASE 28
-#define CONFIG_BLKFMT 29
+#define CONFIG_BLKBASE	28
+#define CONFIG_BLKFMT	29
 #define CONFIG_RESOURCE_DEBUG 30
 #define CONFIG_LIB_DEBUG CONFIG_RESOURCE_DEBUG
 #define CONFIG_CALC_DEBUG 31
 #define CONFIG_USER_DEBUG 32
 #define CONFIG_VERBOSE_QUIT 33
-#define CONFIG_CTRL_D 34
-#define CONFIG_PROGRAM 35
-#define CONFIG_BASENAME 36
-#define CONFIG_VERSION 37
-#define CONFIG_WINDOWS 38
+#define CONFIG_CTRL_D	34
+#define CONFIG_PROGRAM	35
+#define CONFIG_BASENAME	36
+#define CONFIG_VERSION	37
+#define CONFIG_WINDOWS	38
 #define CONFIG_MODE2	39
+#define CONFIG_CYGWIN	40
+#define CONFIG_COMPILE_CUSTOM	41
+#define CONFIG_ALLOW_CUSTOM	42
+#define CONFIG_BASEB	43
+#define CONFIG_REDECL_WARN	44
+#define CONFIG_DUPVAR_WARN	45
+#define CONFIG_HZ	46
 
 
 /*
@@ -99,8 +106,6 @@
 #define DISPLAY_DEFAULT 20	/* default digits for float display */
 #define EPSILON_DEFAULT "1e-20" /* allowed error for float calculations */
 #define EPSILONPREC_DEFAULT 67	/* 67 ==> 2^-67 <= EPSILON_DEFAULT < 2^-66 */
-#define NEW_EPSILON_DEFAULT "1e-10"	/* newstd EPSILON_DEFAULT */
-#define NEW_EPSILONPREC_DEFAULT 34	/* 34 ==> 2^-34 <= 1e-10 < 2^-33 */
 #define MAXPRINT_DEFAULT 16	/* default number of elements printed */
 #define MAXSCANCOUNT 20		/* default max scan errors before an abort */
 
@@ -149,15 +154,21 @@ struct config {
 	BOOL blkverbose;	/* TRUE => print all lines if a block */
 	int blkbase;		/* block output base */
 	int blkfmt;		/* block output style */
-	long calc_debug;	/* internal debug, see CALC_DEBUG_XXX below */
-	long resource_debug;	/* resource debug, see RSCDBG_XXX below */
+	long calc_debug;	/* internal debug, see CALC_DEBUG_XYZ below */
+	long resource_debug;	/* resource debug, see RSCDBG_XYZ below */
 	long user_debug;	/* user defined debug value: 0 default */
 	BOOL verbose_quit;	/* TRUE => print Quit or abort executed msg */
 	int ctrl_d;		/* see CTRL_D_xyz below */
 	char *program;		/* our name */
 	char *base_name;	/* basename of our name */
 	BOOL windows;		/* TRUE => running under MS windows */
+	BOOL cygwin;		/* TRUE => compiled with cygwin */
+	BOOL compile_custom;	/* TRUE => compiled with -DCUSTOM */
+	BOOL *allow_custom;	/* ptr to if custom functions are allowed */
 	char *version;		/* calc version string */
+	int baseb;		/* base for calculations */
+	BOOL redecl_warn;	/* TRUE => warn of redeclating variables */
+	BOOL dupvar_warn;	/* TRUE => warn of var name collisions */
 };
 typedef struct config CONFIG;
 
@@ -182,7 +193,8 @@ typedef struct config CONFIG;
 #define CALCDBG_TTY	    (0x00000010)    /* report TTY state changes */
 #define CALCDBG_RUNSTATE    (0x00000020)    /* report run_state changes */
 #define CALCDBG_RAND	    (0x00000040)    /* report rand() activity */
-#define CALCDBG_MASK	    (0x0000007f)
+#define CALCDBG_CUSTOM	    (0x00000080)    /* custom function debug */
+#define CALCDBG_MASK	    (0x000000ff)
 
 /*
  * ctrl-d meanings
@@ -195,23 +207,23 @@ typedef struct config CONFIG;
 /*
  * global configuration states and aliases
  */
-extern DLL CONFIG *conf;	/* current configuration */
-extern DLL CONFIG oldstd;	/* backward compatible standard configuration */
-extern DLL CONFIG newstd;	/* new non-backward compatible configuration */
-extern DLL char *calc_debug;	/* !=NULL => value of config("calc_debug") */
-extern DLL char *resource_debug; /* !=NULL => config("resource_debug") value */
-extern DLL char *user_debug;	/* !=NULL => value of config("user_debug") */
+EXTERN CONFIG *conf;	/* current configuration */
+EXTERN CONFIG oldstd;	/* old classic standard configuration */
+EXTERN CONFIG newstd;	/* default compatible configuration */
+E_FUNC char *calc_debug;	/* !=NULL => value of config("calc_debug") */
+E_FUNC char *resource_debug; /* !=NULL => config("resource_debug") value */
+E_FUNC char *user_debug;	/* !=NULL => value of config("user_debug") */
 
 
 /*
  * configuration externals
  */
-extern DLL CONFIG *config_copy(CONFIG *src);
-extern DLL void config_free(CONFIG *cfg);
-extern DLL void config_print(CONFIG *cfg);
-extern DLL int configtype(char*);
-extern DLL void config_print(CONFIG*);
-extern DLL BOOL config_cmp(CONFIG*, CONFIG*);
+E_FUNC CONFIG *config_copy(CONFIG *src);
+E_FUNC void config_free(CONFIG *cfg);
+E_FUNC void config_print(CONFIG *cfg);
+E_FUNC int configtype(char*);
+E_FUNC void config_print(CONFIG*);
+E_FUNC BOOL config_cmp(CONFIG*, CONFIG*);
 
 
-#endif /* !__CONFIG_H__ */
+#endif /* !INCLUDE_CONFIG_H */
