@@ -1,7 +1,7 @@
 /*
  * jump - trivial prime jump table
  *
- * Copyright (C) 1999  Landon Curt Noll
+ * Copyright (C) 1999-2007,2014  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -15,11 +15,11 @@
  * A copy of version 2.1 of the GNU Lesser General Public License is
  * distributed with calc under the filename COPYING-LGPL.  You should have
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 29.4 $
- * @(#) $Id: jump.h,v 29.4 2001/06/08 21:00:58 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/jump.h,v $
+ * @(#) $Revision: 30.3 $
+ * @(#) $Id: jump.h,v 30.3 2014/08/24 21:56:51 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/jump.h,v $
  *
  * Under source code control:	1994/06/29 04:03:55
  * File existed as early as:	1994
@@ -62,14 +62,16 @@
  */
 
 
-#if !defined(__JUMP_H__)
-#define __JUMP_H__
+#if !defined(INCLUDE_JUMP_H)
+#define INCLUDE_JUMP_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
 # include "calc/have_const.h"
+# include "calc/decl.h"
 #else
 # include <calc/have_const.h>
+# include <calc/decl.h>
 #endif
 
 
@@ -101,8 +103,8 @@
 /*
  * external jump tables
  */
-extern CONST short jmpindx[];
-extern CONST unsigned char jmp[];
-extern CONST unsigned char *CONST lastjmp;
+EXTERN CONST short jmpindx[];
+EXTERN CONST unsigned char jmp[];
+EXTERN CONST unsigned char *CONST lastjmp;
 
-#endif /* !__JUMP_H__ */
+#endif /* !INCLUDE_JUMP_H */
