@@ -1,7 +1,7 @@
 /*
  * label - label handling routines
  *
- * Copyright (C) 1999  David I. Bell
+ * Copyright (C) 1999-2007,2014  David I. Bell
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -15,11 +15,11 @@
  * A copy of version 2.1 of the GNU Lesser General Public License is
  * distributed with calc under the filename COPYING-LGPL.  You should have
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 29.4 $
- * @(#) $Id: label.h,v 29.4 2001/06/08 21:00:58 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/label.h,v $
+ * @(#) $Revision: 30.3 $
+ * @(#) $Id: label.h,v 30.3 2014/08/24 21:56:51 chongo Exp $
+ * @(#) $Source: /usr/local/src/bin/calc/RCS/label.h,v $
  *
  * Under source code control:	1990/02/15 01:48:33
  * File existed as early as:	before 1990
@@ -28,8 +28,8 @@
  */
 
 
-#if !defined(__LABEL_H__)
-#define __LABEL_H__
+#if !defined(INCLUDE_LABEL_H)
+#define INCLUDE_LABEL_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
@@ -52,13 +52,13 @@ typedef struct {
 } LABEL;
 
 
-extern void initlabels(void);
-extern void definelabel(char *name);
-extern void addlabel(char *name);
-extern void clearlabel(LABEL *lp);
-extern void setlabel(LABEL *lp);
-extern void uselabel(LABEL *lp);
-extern void checklabels(void);
+E_FUNC void initlabels(void);
+E_FUNC void definelabel(char *name);
+E_FUNC void addlabel(char *name);
+E_FUNC void clearlabel(LABEL *lp);
+E_FUNC void setlabel(LABEL *lp);
+E_FUNC void uselabel(LABEL *lp);
+E_FUNC void checklabels(void);
 
 
-#endif /* !__LABEL_H__ */
+#endif /* !INCLUDE_LABEL_H */
